@@ -67,6 +67,7 @@ from .type_defs import (
     WorkflowDetailsTypeDef,
     WorkflowStepTypeDef,
 )
+from .waiter import ServerOfflineWaiter, ServerOnlineWaiter
 
 if sys.version_info >= (3, 9):
     from typing import Literal
@@ -588,3 +589,17 @@ class TransferClient(BaseClient):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#get_paginator)
         """
+
+    @overload
+    def get_waiter(self, waiter_name: Literal["server_offline"]) -> ServerOfflineWaiter:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_waiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#get_waiter)
+        """
+
+    @overload
+    def get_waiter(self, waiter_name: Literal["server_online"]) -> ServerOnlineWaiter:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_waiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#get_waiter)
+        """
