@@ -15,10 +15,13 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     CustomStepStatusType,
     DomainType,
     EndpointTypeType,
+    ExecutionErrorTypeType,
     ExecutionStatusType,
     HomeDirectoryTypeType,
     IdentityProviderTypeType,
@@ -29,10 +32,6 @@ from .literals import (
     WorkflowStepTypeType,
 )
 
-if sys.version_info >= (3, 9):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -130,6 +129,7 @@ __all__ = (
     "UpdateUserRequestRequestTypeDef",
     "UpdateUserResponseTypeDef",
     "UserDetailsTypeDef",
+    "WaiterConfigTypeDef",
     "WorkflowDetailTypeDef",
     "WorkflowDetailsTypeDef",
     "WorkflowStepTypeDef",
@@ -138,40 +138,26 @@ __all__ = (
 CopyStepDetailsTypeDef = TypedDict(
     "CopyStepDetailsTypeDef",
     {
-        "Name": str,
-        "DestinationFileLocation": "InputFileLocationTypeDef",
-        "OverwriteExisting": OverwriteExistingType,
-        "SourceFileLocation": str,
+        "Name": NotRequired[str],
+        "DestinationFileLocation": NotRequired["InputFileLocationTypeDef"],
+        "OverwriteExisting": NotRequired[OverwriteExistingType],
+        "SourceFileLocation": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredCreateAccessRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAccessRequestRequestTypeDef",
+CreateAccessRequestRequestTypeDef = TypedDict(
+    "CreateAccessRequestRequestTypeDef",
     {
         "Role": str,
         "ServerId": str,
         "ExternalId": str,
+        "HomeDirectory": NotRequired[str],
+        "HomeDirectoryType": NotRequired[HomeDirectoryTypeType],
+        "HomeDirectoryMappings": NotRequired[Sequence["HomeDirectoryMapEntryTypeDef"]],
+        "Policy": NotRequired[str],
+        "PosixProfile": NotRequired["PosixProfileTypeDef"],
     },
 )
-_OptionalCreateAccessRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAccessRequestRequestTypeDef",
-    {
-        "HomeDirectory": str,
-        "HomeDirectoryType": HomeDirectoryTypeType,
-        "HomeDirectoryMappings": Sequence["HomeDirectoryMapEntryTypeDef"],
-        "Policy": str,
-        "PosixProfile": "PosixProfileTypeDef",
-    },
-    total=False,
-)
-
-
-class CreateAccessRequestRequestTypeDef(
-    _RequiredCreateAccessRequestRequestTypeDef, _OptionalCreateAccessRequestRequestTypeDef
-):
-    pass
-
 
 CreateAccessResponseTypeDef = TypedDict(
     "CreateAccessResponseTypeDef",
@@ -185,23 +171,22 @@ CreateAccessResponseTypeDef = TypedDict(
 CreateServerRequestRequestTypeDef = TypedDict(
     "CreateServerRequestRequestTypeDef",
     {
-        "Certificate": str,
-        "Domain": DomainType,
-        "EndpointDetails": "EndpointDetailsTypeDef",
-        "EndpointType": EndpointTypeType,
-        "HostKey": str,
-        "IdentityProviderDetails": "IdentityProviderDetailsTypeDef",
-        "IdentityProviderType": IdentityProviderTypeType,
-        "LoggingRole": str,
-        "PostAuthenticationLoginBanner": str,
-        "PreAuthenticationLoginBanner": str,
-        "Protocols": Sequence[ProtocolType],
-        "ProtocolDetails": "ProtocolDetailsTypeDef",
-        "SecurityPolicyName": str,
-        "Tags": Sequence["TagTypeDef"],
-        "WorkflowDetails": "WorkflowDetailsTypeDef",
+        "Certificate": NotRequired[str],
+        "Domain": NotRequired[DomainType],
+        "EndpointDetails": NotRequired["EndpointDetailsTypeDef"],
+        "EndpointType": NotRequired[EndpointTypeType],
+        "HostKey": NotRequired[str],
+        "IdentityProviderDetails": NotRequired["IdentityProviderDetailsTypeDef"],
+        "IdentityProviderType": NotRequired[IdentityProviderTypeType],
+        "LoggingRole": NotRequired[str],
+        "PostAuthenticationLoginBanner": NotRequired[str],
+        "PreAuthenticationLoginBanner": NotRequired[str],
+        "Protocols": NotRequired[Sequence[ProtocolType]],
+        "ProtocolDetails": NotRequired["ProtocolDetailsTypeDef"],
+        "SecurityPolicyName": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
+        "WorkflowDetails": NotRequired["WorkflowDetailsTypeDef"],
     },
-    total=False,
 )
 
 CreateServerResponseTypeDef = TypedDict(
@@ -212,34 +197,21 @@ CreateServerResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateUserRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateUserRequestRequestTypeDef",
+CreateUserRequestRequestTypeDef = TypedDict(
+    "CreateUserRequestRequestTypeDef",
     {
         "Role": str,
         "ServerId": str,
         "UserName": str,
+        "HomeDirectory": NotRequired[str],
+        "HomeDirectoryType": NotRequired[HomeDirectoryTypeType],
+        "HomeDirectoryMappings": NotRequired[Sequence["HomeDirectoryMapEntryTypeDef"]],
+        "Policy": NotRequired[str],
+        "PosixProfile": NotRequired["PosixProfileTypeDef"],
+        "SshPublicKeyBody": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateUserRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateUserRequestRequestTypeDef",
-    {
-        "HomeDirectory": str,
-        "HomeDirectoryType": HomeDirectoryTypeType,
-        "HomeDirectoryMappings": Sequence["HomeDirectoryMapEntryTypeDef"],
-        "Policy": str,
-        "PosixProfile": "PosixProfileTypeDef",
-        "SshPublicKeyBody": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateUserRequestRequestTypeDef(
-    _RequiredCreateUserRequestRequestTypeDef, _OptionalCreateUserRequestRequestTypeDef
-):
-    pass
-
 
 CreateUserResponseTypeDef = TypedDict(
     "CreateUserResponseTypeDef",
@@ -250,28 +222,15 @@ CreateUserResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateWorkflowRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateWorkflowRequestRequestTypeDef",
+CreateWorkflowRequestRequestTypeDef = TypedDict(
+    "CreateWorkflowRequestRequestTypeDef",
     {
         "Steps": Sequence["WorkflowStepTypeDef"],
+        "Description": NotRequired[str],
+        "OnExceptionSteps": NotRequired[Sequence["WorkflowStepTypeDef"]],
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateWorkflowRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateWorkflowRequestRequestTypeDef",
-    {
-        "Description": str,
-        "OnExceptionSteps": Sequence["WorkflowStepTypeDef"],
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateWorkflowRequestRequestTypeDef(
-    _RequiredCreateWorkflowRequestRequestTypeDef, _OptionalCreateWorkflowRequestRequestTypeDef
-):
-    pass
-
 
 CreateWorkflowResponseTypeDef = TypedDict(
     "CreateWorkflowResponseTypeDef",
@@ -284,12 +243,11 @@ CreateWorkflowResponseTypeDef = TypedDict(
 CustomStepDetailsTypeDef = TypedDict(
     "CustomStepDetailsTypeDef",
     {
-        "Name": str,
-        "Target": str,
-        "TimeoutSeconds": int,
-        "SourceFileLocation": str,
+        "Name": NotRequired[str],
+        "Target": NotRequired[str],
+        "TimeoutSeconds": NotRequired[int],
+        "SourceFileLocation": NotRequired[str],
     },
-    total=False,
 )
 
 DeleteAccessRequestRequestTypeDef = TypedDict(
@@ -319,10 +277,9 @@ DeleteSshPublicKeyRequestRequestTypeDef = TypedDict(
 DeleteStepDetailsTypeDef = TypedDict(
     "DeleteStepDetailsTypeDef",
     {
-        "Name": str,
-        "SourceFileLocation": str,
+        "Name": NotRequired[str],
+        "SourceFileLocation": NotRequired[str],
     },
-    total=False,
 )
 
 DeleteUserRequestRequestTypeDef = TypedDict(
@@ -439,170 +396,118 @@ DescribeWorkflowResponseTypeDef = TypedDict(
 DescribedAccessTypeDef = TypedDict(
     "DescribedAccessTypeDef",
     {
-        "HomeDirectory": str,
-        "HomeDirectoryMappings": List["HomeDirectoryMapEntryTypeDef"],
-        "HomeDirectoryType": HomeDirectoryTypeType,
-        "Policy": str,
-        "PosixProfile": "PosixProfileTypeDef",
-        "Role": str,
-        "ExternalId": str,
+        "HomeDirectory": NotRequired[str],
+        "HomeDirectoryMappings": NotRequired[List["HomeDirectoryMapEntryTypeDef"]],
+        "HomeDirectoryType": NotRequired[HomeDirectoryTypeType],
+        "Policy": NotRequired[str],
+        "PosixProfile": NotRequired["PosixProfileTypeDef"],
+        "Role": NotRequired[str],
+        "ExternalId": NotRequired[str],
     },
-    total=False,
 )
 
 DescribedExecutionTypeDef = TypedDict(
     "DescribedExecutionTypeDef",
     {
-        "ExecutionId": str,
-        "InitialFileLocation": "FileLocationTypeDef",
-        "ServiceMetadata": "ServiceMetadataTypeDef",
-        "ExecutionRole": str,
-        "LoggingConfiguration": "LoggingConfigurationTypeDef",
-        "PosixProfile": "PosixProfileTypeDef",
-        "Status": ExecutionStatusType,
-        "Results": "ExecutionResultsTypeDef",
+        "ExecutionId": NotRequired[str],
+        "InitialFileLocation": NotRequired["FileLocationTypeDef"],
+        "ServiceMetadata": NotRequired["ServiceMetadataTypeDef"],
+        "ExecutionRole": NotRequired[str],
+        "LoggingConfiguration": NotRequired["LoggingConfigurationTypeDef"],
+        "PosixProfile": NotRequired["PosixProfileTypeDef"],
+        "Status": NotRequired[ExecutionStatusType],
+        "Results": NotRequired["ExecutionResultsTypeDef"],
     },
-    total=False,
 )
 
-_RequiredDescribedSecurityPolicyTypeDef = TypedDict(
-    "_RequiredDescribedSecurityPolicyTypeDef",
+DescribedSecurityPolicyTypeDef = TypedDict(
+    "DescribedSecurityPolicyTypeDef",
     {
         "SecurityPolicyName": str,
+        "Fips": NotRequired[bool],
+        "SshCiphers": NotRequired[List[str]],
+        "SshKexs": NotRequired[List[str]],
+        "SshMacs": NotRequired[List[str]],
+        "TlsCiphers": NotRequired[List[str]],
     },
 )
-_OptionalDescribedSecurityPolicyTypeDef = TypedDict(
-    "_OptionalDescribedSecurityPolicyTypeDef",
-    {
-        "Fips": bool,
-        "SshCiphers": List[str],
-        "SshKexs": List[str],
-        "SshMacs": List[str],
-        "TlsCiphers": List[str],
-    },
-    total=False,
-)
 
-
-class DescribedSecurityPolicyTypeDef(
-    _RequiredDescribedSecurityPolicyTypeDef, _OptionalDescribedSecurityPolicyTypeDef
-):
-    pass
-
-
-_RequiredDescribedServerTypeDef = TypedDict(
-    "_RequiredDescribedServerTypeDef",
+DescribedServerTypeDef = TypedDict(
+    "DescribedServerTypeDef",
     {
         "Arn": str,
+        "Certificate": NotRequired[str],
+        "ProtocolDetails": NotRequired["ProtocolDetailsTypeDef"],
+        "Domain": NotRequired[DomainType],
+        "EndpointDetails": NotRequired["EndpointDetailsTypeDef"],
+        "EndpointType": NotRequired[EndpointTypeType],
+        "HostKeyFingerprint": NotRequired[str],
+        "IdentityProviderDetails": NotRequired["IdentityProviderDetailsTypeDef"],
+        "IdentityProviderType": NotRequired[IdentityProviderTypeType],
+        "LoggingRole": NotRequired[str],
+        "PostAuthenticationLoginBanner": NotRequired[str],
+        "PreAuthenticationLoginBanner": NotRequired[str],
+        "Protocols": NotRequired[List[ProtocolType]],
+        "SecurityPolicyName": NotRequired[str],
+        "ServerId": NotRequired[str],
+        "State": NotRequired[StateType],
+        "Tags": NotRequired[List["TagTypeDef"]],
+        "UserCount": NotRequired[int],
+        "WorkflowDetails": NotRequired["WorkflowDetailsTypeDef"],
     },
 )
-_OptionalDescribedServerTypeDef = TypedDict(
-    "_OptionalDescribedServerTypeDef",
-    {
-        "Certificate": str,
-        "ProtocolDetails": "ProtocolDetailsTypeDef",
-        "Domain": DomainType,
-        "EndpointDetails": "EndpointDetailsTypeDef",
-        "EndpointType": EndpointTypeType,
-        "HostKeyFingerprint": str,
-        "IdentityProviderDetails": "IdentityProviderDetailsTypeDef",
-        "IdentityProviderType": IdentityProviderTypeType,
-        "LoggingRole": str,
-        "PostAuthenticationLoginBanner": str,
-        "PreAuthenticationLoginBanner": str,
-        "Protocols": List[ProtocolType],
-        "SecurityPolicyName": str,
-        "ServerId": str,
-        "State": StateType,
-        "Tags": List["TagTypeDef"],
-        "UserCount": int,
-        "WorkflowDetails": "WorkflowDetailsTypeDef",
-    },
-    total=False,
-)
 
-
-class DescribedServerTypeDef(_RequiredDescribedServerTypeDef, _OptionalDescribedServerTypeDef):
-    pass
-
-
-_RequiredDescribedUserTypeDef = TypedDict(
-    "_RequiredDescribedUserTypeDef",
+DescribedUserTypeDef = TypedDict(
+    "DescribedUserTypeDef",
     {
         "Arn": str,
+        "HomeDirectory": NotRequired[str],
+        "HomeDirectoryMappings": NotRequired[List["HomeDirectoryMapEntryTypeDef"]],
+        "HomeDirectoryType": NotRequired[HomeDirectoryTypeType],
+        "Policy": NotRequired[str],
+        "PosixProfile": NotRequired["PosixProfileTypeDef"],
+        "Role": NotRequired[str],
+        "SshPublicKeys": NotRequired[List["SshPublicKeyTypeDef"]],
+        "Tags": NotRequired[List["TagTypeDef"]],
+        "UserName": NotRequired[str],
     },
 )
-_OptionalDescribedUserTypeDef = TypedDict(
-    "_OptionalDescribedUserTypeDef",
-    {
-        "HomeDirectory": str,
-        "HomeDirectoryMappings": List["HomeDirectoryMapEntryTypeDef"],
-        "HomeDirectoryType": HomeDirectoryTypeType,
-        "Policy": str,
-        "PosixProfile": "PosixProfileTypeDef",
-        "Role": str,
-        "SshPublicKeys": List["SshPublicKeyTypeDef"],
-        "Tags": List["TagTypeDef"],
-        "UserName": str,
-    },
-    total=False,
-)
 
-
-class DescribedUserTypeDef(_RequiredDescribedUserTypeDef, _OptionalDescribedUserTypeDef):
-    pass
-
-
-_RequiredDescribedWorkflowTypeDef = TypedDict(
-    "_RequiredDescribedWorkflowTypeDef",
+DescribedWorkflowTypeDef = TypedDict(
+    "DescribedWorkflowTypeDef",
     {
         "Arn": str,
+        "Description": NotRequired[str],
+        "Steps": NotRequired[List["WorkflowStepTypeDef"]],
+        "OnExceptionSteps": NotRequired[List["WorkflowStepTypeDef"]],
+        "WorkflowId": NotRequired[str],
+        "Tags": NotRequired[List["TagTypeDef"]],
     },
 )
-_OptionalDescribedWorkflowTypeDef = TypedDict(
-    "_OptionalDescribedWorkflowTypeDef",
-    {
-        "Description": str,
-        "Steps": List["WorkflowStepTypeDef"],
-        "OnExceptionSteps": List["WorkflowStepTypeDef"],
-        "WorkflowId": str,
-        "Tags": List["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class DescribedWorkflowTypeDef(
-    _RequiredDescribedWorkflowTypeDef, _OptionalDescribedWorkflowTypeDef
-):
-    pass
-
 
 EfsFileLocationTypeDef = TypedDict(
     "EfsFileLocationTypeDef",
     {
-        "FileSystemId": str,
-        "Path": str,
+        "FileSystemId": NotRequired[str],
+        "Path": NotRequired[str],
     },
-    total=False,
 )
 
 EndpointDetailsTypeDef = TypedDict(
     "EndpointDetailsTypeDef",
     {
-        "AddressAllocationIds": Sequence[str],
-        "SubnetIds": Sequence[str],
-        "VpcEndpointId": str,
-        "VpcId": str,
-        "SecurityGroupIds": Sequence[str],
+        "AddressAllocationIds": NotRequired[Sequence[str]],
+        "SubnetIds": NotRequired[Sequence[str]],
+        "VpcEndpointId": NotRequired[str],
+        "VpcId": NotRequired[str],
+        "SecurityGroupIds": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 ExecutionErrorTypeDef = TypedDict(
     "ExecutionErrorTypeDef",
     {
-        "Type": Literal["PERMISSION_DENIED"],
+        "Type": ExecutionErrorTypeType,
         "Message": str,
     },
 )
@@ -610,29 +515,26 @@ ExecutionErrorTypeDef = TypedDict(
 ExecutionResultsTypeDef = TypedDict(
     "ExecutionResultsTypeDef",
     {
-        "Steps": List["ExecutionStepResultTypeDef"],
-        "OnExceptionSteps": List["ExecutionStepResultTypeDef"],
+        "Steps": NotRequired[List["ExecutionStepResultTypeDef"]],
+        "OnExceptionSteps": NotRequired[List["ExecutionStepResultTypeDef"]],
     },
-    total=False,
 )
 
 ExecutionStepResultTypeDef = TypedDict(
     "ExecutionStepResultTypeDef",
     {
-        "StepType": WorkflowStepTypeType,
-        "Outputs": str,
-        "Error": "ExecutionErrorTypeDef",
+        "StepType": NotRequired[WorkflowStepTypeType],
+        "Outputs": NotRequired[str],
+        "Error": NotRequired["ExecutionErrorTypeDef"],
     },
-    total=False,
 )
 
 FileLocationTypeDef = TypedDict(
     "FileLocationTypeDef",
     {
-        "S3FileLocation": "S3FileLocationTypeDef",
-        "EfsFileLocation": "EfsFileLocationTypeDef",
+        "S3FileLocation": NotRequired["S3FileLocationTypeDef"],
+        "EfsFileLocation": NotRequired["EfsFileLocationTypeDef"],
     },
-    total=False,
 )
 
 HomeDirectoryMapEntryTypeDef = TypedDict(
@@ -646,12 +548,11 @@ HomeDirectoryMapEntryTypeDef = TypedDict(
 IdentityProviderDetailsTypeDef = TypedDict(
     "IdentityProviderDetailsTypeDef",
     {
-        "Url": str,
-        "InvocationRole": str,
-        "DirectoryId": str,
-        "Function": str,
+        "Url": NotRequired[str],
+        "InvocationRole": NotRequired[str],
+        "DirectoryId": NotRequired[str],
+        "Function": NotRequired[str],
     },
-    total=False,
 )
 
 ImportSshPublicKeyRequestRequestTypeDef = TypedDict(
@@ -676,33 +577,19 @@ ImportSshPublicKeyResponseTypeDef = TypedDict(
 InputFileLocationTypeDef = TypedDict(
     "InputFileLocationTypeDef",
     {
-        "S3FileLocation": "S3InputFileLocationTypeDef",
-        "EfsFileLocation": "EfsFileLocationTypeDef",
+        "S3FileLocation": NotRequired["S3InputFileLocationTypeDef"],
+        "EfsFileLocation": NotRequired["EfsFileLocationTypeDef"],
     },
-    total=False,
 )
 
-_RequiredListAccessesRequestRequestTypeDef = TypedDict(
-    "_RequiredListAccessesRequestRequestTypeDef",
+ListAccessesRequestRequestTypeDef = TypedDict(
+    "ListAccessesRequestRequestTypeDef",
     {
         "ServerId": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListAccessesRequestRequestTypeDef = TypedDict(
-    "_OptionalListAccessesRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListAccessesRequestRequestTypeDef(
-    _RequiredListAccessesRequestRequestTypeDef, _OptionalListAccessesRequestRequestTypeDef
-):
-    pass
-
 
 ListAccessesResponseTypeDef = TypedDict(
     "ListAccessesResponseTypeDef",
@@ -714,27 +601,14 @@ ListAccessesResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListExecutionsRequestRequestTypeDef = TypedDict(
-    "_RequiredListExecutionsRequestRequestTypeDef",
+ListExecutionsRequestRequestTypeDef = TypedDict(
+    "ListExecutionsRequestRequestTypeDef",
     {
         "WorkflowId": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListExecutionsRequestRequestTypeDef = TypedDict(
-    "_OptionalListExecutionsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListExecutionsRequestRequestTypeDef(
-    _RequiredListExecutionsRequestRequestTypeDef, _OptionalListExecutionsRequestRequestTypeDef
-):
-    pass
-
 
 ListExecutionsResponseTypeDef = TypedDict(
     "ListExecutionsResponseTypeDef",
@@ -749,10 +623,9 @@ ListExecutionsResponseTypeDef = TypedDict(
 ListSecurityPoliciesRequestRequestTypeDef = TypedDict(
     "ListSecurityPoliciesRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListSecurityPoliciesResponseTypeDef = TypedDict(
@@ -767,10 +640,9 @@ ListSecurityPoliciesResponseTypeDef = TypedDict(
 ListServersRequestRequestTypeDef = TypedDict(
     "ListServersRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListServersResponseTypeDef = TypedDict(
@@ -782,28 +654,14 @@ ListServersResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "_RequiredListTagsForResourceRequestRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "Arn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "_OptionalListTagsForResourceRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListTagsForResourceRequestRequestTypeDef(
-    _RequiredListTagsForResourceRequestRequestTypeDef,
-    _OptionalListTagsForResourceRequestRequestTypeDef,
-):
-    pass
-
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
@@ -815,27 +673,14 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListUsersRequestRequestTypeDef = TypedDict(
-    "_RequiredListUsersRequestRequestTypeDef",
+ListUsersRequestRequestTypeDef = TypedDict(
+    "ListUsersRequestRequestTypeDef",
     {
         "ServerId": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListUsersRequestRequestTypeDef = TypedDict(
-    "_OptionalListUsersRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListUsersRequestRequestTypeDef(
-    _RequiredListUsersRequestRequestTypeDef, _OptionalListUsersRequestRequestTypeDef
-):
-    pass
-
 
 ListUsersResponseTypeDef = TypedDict(
     "ListUsersResponseTypeDef",
@@ -850,10 +695,9 @@ ListUsersResponseTypeDef = TypedDict(
 ListWorkflowsRequestRequestTypeDef = TypedDict(
     "ListWorkflowsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListWorkflowsResponseTypeDef = TypedDict(
@@ -868,129 +712,90 @@ ListWorkflowsResponseTypeDef = TypedDict(
 ListedAccessTypeDef = TypedDict(
     "ListedAccessTypeDef",
     {
-        "HomeDirectory": str,
-        "HomeDirectoryType": HomeDirectoryTypeType,
-        "Role": str,
-        "ExternalId": str,
+        "HomeDirectory": NotRequired[str],
+        "HomeDirectoryType": NotRequired[HomeDirectoryTypeType],
+        "Role": NotRequired[str],
+        "ExternalId": NotRequired[str],
     },
-    total=False,
 )
 
 ListedExecutionTypeDef = TypedDict(
     "ListedExecutionTypeDef",
     {
-        "ExecutionId": str,
-        "InitialFileLocation": "FileLocationTypeDef",
-        "ServiceMetadata": "ServiceMetadataTypeDef",
-        "Status": ExecutionStatusType,
+        "ExecutionId": NotRequired[str],
+        "InitialFileLocation": NotRequired["FileLocationTypeDef"],
+        "ServiceMetadata": NotRequired["ServiceMetadataTypeDef"],
+        "Status": NotRequired[ExecutionStatusType],
     },
-    total=False,
 )
 
-_RequiredListedServerTypeDef = TypedDict(
-    "_RequiredListedServerTypeDef",
+ListedServerTypeDef = TypedDict(
+    "ListedServerTypeDef",
     {
         "Arn": str,
+        "Domain": NotRequired[DomainType],
+        "IdentityProviderType": NotRequired[IdentityProviderTypeType],
+        "EndpointType": NotRequired[EndpointTypeType],
+        "LoggingRole": NotRequired[str],
+        "ServerId": NotRequired[str],
+        "State": NotRequired[StateType],
+        "UserCount": NotRequired[int],
     },
 )
-_OptionalListedServerTypeDef = TypedDict(
-    "_OptionalListedServerTypeDef",
-    {
-        "Domain": DomainType,
-        "IdentityProviderType": IdentityProviderTypeType,
-        "EndpointType": EndpointTypeType,
-        "LoggingRole": str,
-        "ServerId": str,
-        "State": StateType,
-        "UserCount": int,
-    },
-    total=False,
-)
 
-
-class ListedServerTypeDef(_RequiredListedServerTypeDef, _OptionalListedServerTypeDef):
-    pass
-
-
-_RequiredListedUserTypeDef = TypedDict(
-    "_RequiredListedUserTypeDef",
+ListedUserTypeDef = TypedDict(
+    "ListedUserTypeDef",
     {
         "Arn": str,
+        "HomeDirectory": NotRequired[str],
+        "HomeDirectoryType": NotRequired[HomeDirectoryTypeType],
+        "Role": NotRequired[str],
+        "SshPublicKeyCount": NotRequired[int],
+        "UserName": NotRequired[str],
     },
 )
-_OptionalListedUserTypeDef = TypedDict(
-    "_OptionalListedUserTypeDef",
-    {
-        "HomeDirectory": str,
-        "HomeDirectoryType": HomeDirectoryTypeType,
-        "Role": str,
-        "SshPublicKeyCount": int,
-        "UserName": str,
-    },
-    total=False,
-)
-
-
-class ListedUserTypeDef(_RequiredListedUserTypeDef, _OptionalListedUserTypeDef):
-    pass
-
 
 ListedWorkflowTypeDef = TypedDict(
     "ListedWorkflowTypeDef",
     {
-        "WorkflowId": str,
-        "Description": str,
-        "Arn": str,
+        "WorkflowId": NotRequired[str],
+        "Description": NotRequired[str],
+        "Arn": NotRequired[str],
     },
-    total=False,
 )
 
 LoggingConfigurationTypeDef = TypedDict(
     "LoggingConfigurationTypeDef",
     {
-        "LoggingRole": str,
-        "LogGroupName": str,
+        "LoggingRole": NotRequired[str],
+        "LogGroupName": NotRequired[str],
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredPosixProfileTypeDef = TypedDict(
-    "_RequiredPosixProfileTypeDef",
+PosixProfileTypeDef = TypedDict(
+    "PosixProfileTypeDef",
     {
         "Uid": int,
         "Gid": int,
+        "SecondaryGids": NotRequired[Sequence[int]],
     },
 )
-_OptionalPosixProfileTypeDef = TypedDict(
-    "_OptionalPosixProfileTypeDef",
-    {
-        "SecondaryGids": Sequence[int],
-    },
-    total=False,
-)
-
-
-class PosixProfileTypeDef(_RequiredPosixProfileTypeDef, _OptionalPosixProfileTypeDef):
-    pass
-
 
 ProtocolDetailsTypeDef = TypedDict(
     "ProtocolDetailsTypeDef",
     {
-        "PassiveIp": str,
-        "TlsSessionResumptionMode": TlsSessionResumptionModeType,
+        "PassiveIp": NotRequired[str],
+        "TlsSessionResumptionMode": NotRequired[TlsSessionResumptionModeType],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -1007,21 +812,19 @@ ResponseMetadataTypeDef = TypedDict(
 S3FileLocationTypeDef = TypedDict(
     "S3FileLocationTypeDef",
     {
-        "Bucket": str,
-        "Key": str,
-        "VersionId": str,
-        "Etag": str,
+        "Bucket": NotRequired[str],
+        "Key": NotRequired[str],
+        "VersionId": NotRequired[str],
+        "Etag": NotRequired[str],
     },
-    total=False,
 )
 
 S3InputFileLocationTypeDef = TypedDict(
     "S3InputFileLocationTypeDef",
     {
-        "Bucket": str,
-        "Key": str,
+        "Bucket": NotRequired[str],
+        "Key": NotRequired[str],
     },
-    total=False,
 )
 
 S3TagTypeDef = TypedDict(
@@ -1083,11 +886,10 @@ TagResourceRequestRequestTypeDef = TypedDict(
 TagStepDetailsTypeDef = TypedDict(
     "TagStepDetailsTypeDef",
     {
-        "Name": str,
-        "Tags": Sequence["S3TagTypeDef"],
-        "SourceFileLocation": str,
+        "Name": NotRequired[str],
+        "Tags": NotRequired[Sequence["S3TagTypeDef"]],
+        "SourceFileLocation": NotRequired[str],
     },
-    total=False,
 )
 
 TagTypeDef = TypedDict(
@@ -1098,30 +900,16 @@ TagTypeDef = TypedDict(
     },
 )
 
-_RequiredTestIdentityProviderRequestRequestTypeDef = TypedDict(
-    "_RequiredTestIdentityProviderRequestRequestTypeDef",
+TestIdentityProviderRequestRequestTypeDef = TypedDict(
+    "TestIdentityProviderRequestRequestTypeDef",
     {
         "ServerId": str,
         "UserName": str,
+        "ServerProtocol": NotRequired[ProtocolType],
+        "SourceIp": NotRequired[str],
+        "UserPassword": NotRequired[str],
     },
 )
-_OptionalTestIdentityProviderRequestRequestTypeDef = TypedDict(
-    "_OptionalTestIdentityProviderRequestRequestTypeDef",
-    {
-        "ServerProtocol": ProtocolType,
-        "SourceIp": str,
-        "UserPassword": str,
-    },
-    total=False,
-)
-
-
-class TestIdentityProviderRequestRequestTypeDef(
-    _RequiredTestIdentityProviderRequestRequestTypeDef,
-    _OptionalTestIdentityProviderRequestRequestTypeDef,
-):
-    pass
-
 
 TestIdentityProviderResponseTypeDef = TypedDict(
     "TestIdentityProviderResponseTypeDef",
@@ -1142,32 +930,19 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateAccessRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateAccessRequestRequestTypeDef",
+UpdateAccessRequestRequestTypeDef = TypedDict(
+    "UpdateAccessRequestRequestTypeDef",
     {
         "ServerId": str,
         "ExternalId": str,
+        "HomeDirectory": NotRequired[str],
+        "HomeDirectoryType": NotRequired[HomeDirectoryTypeType],
+        "HomeDirectoryMappings": NotRequired[Sequence["HomeDirectoryMapEntryTypeDef"]],
+        "Policy": NotRequired[str],
+        "PosixProfile": NotRequired["PosixProfileTypeDef"],
+        "Role": NotRequired[str],
     },
 )
-_OptionalUpdateAccessRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateAccessRequestRequestTypeDef",
-    {
-        "HomeDirectory": str,
-        "HomeDirectoryType": HomeDirectoryTypeType,
-        "HomeDirectoryMappings": Sequence["HomeDirectoryMapEntryTypeDef"],
-        "Policy": str,
-        "PosixProfile": "PosixProfileTypeDef",
-        "Role": str,
-    },
-    total=False,
-)
-
-
-class UpdateAccessRequestRequestTypeDef(
-    _RequiredUpdateAccessRequestRequestTypeDef, _OptionalUpdateAccessRequestRequestTypeDef
-):
-    pass
-
 
 UpdateAccessResponseTypeDef = TypedDict(
     "UpdateAccessResponseTypeDef",
@@ -1178,37 +953,24 @@ UpdateAccessResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateServerRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateServerRequestRequestTypeDef",
+UpdateServerRequestRequestTypeDef = TypedDict(
+    "UpdateServerRequestRequestTypeDef",
     {
         "ServerId": str,
+        "Certificate": NotRequired[str],
+        "ProtocolDetails": NotRequired["ProtocolDetailsTypeDef"],
+        "EndpointDetails": NotRequired["EndpointDetailsTypeDef"],
+        "EndpointType": NotRequired[EndpointTypeType],
+        "HostKey": NotRequired[str],
+        "IdentityProviderDetails": NotRequired["IdentityProviderDetailsTypeDef"],
+        "LoggingRole": NotRequired[str],
+        "PostAuthenticationLoginBanner": NotRequired[str],
+        "PreAuthenticationLoginBanner": NotRequired[str],
+        "Protocols": NotRequired[Sequence[ProtocolType]],
+        "SecurityPolicyName": NotRequired[str],
+        "WorkflowDetails": NotRequired["WorkflowDetailsTypeDef"],
     },
 )
-_OptionalUpdateServerRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateServerRequestRequestTypeDef",
-    {
-        "Certificate": str,
-        "ProtocolDetails": "ProtocolDetailsTypeDef",
-        "EndpointDetails": "EndpointDetailsTypeDef",
-        "EndpointType": EndpointTypeType,
-        "HostKey": str,
-        "IdentityProviderDetails": "IdentityProviderDetailsTypeDef",
-        "LoggingRole": str,
-        "PostAuthenticationLoginBanner": str,
-        "PreAuthenticationLoginBanner": str,
-        "Protocols": Sequence[ProtocolType],
-        "SecurityPolicyName": str,
-        "WorkflowDetails": "WorkflowDetailsTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateServerRequestRequestTypeDef(
-    _RequiredUpdateServerRequestRequestTypeDef, _OptionalUpdateServerRequestRequestTypeDef
-):
-    pass
-
 
 UpdateServerResponseTypeDef = TypedDict(
     "UpdateServerResponseTypeDef",
@@ -1218,32 +980,19 @@ UpdateServerResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateUserRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateUserRequestRequestTypeDef",
+UpdateUserRequestRequestTypeDef = TypedDict(
+    "UpdateUserRequestRequestTypeDef",
     {
         "ServerId": str,
         "UserName": str,
+        "HomeDirectory": NotRequired[str],
+        "HomeDirectoryType": NotRequired[HomeDirectoryTypeType],
+        "HomeDirectoryMappings": NotRequired[Sequence["HomeDirectoryMapEntryTypeDef"]],
+        "Policy": NotRequired[str],
+        "PosixProfile": NotRequired["PosixProfileTypeDef"],
+        "Role": NotRequired[str],
     },
 )
-_OptionalUpdateUserRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateUserRequestRequestTypeDef",
-    {
-        "HomeDirectory": str,
-        "HomeDirectoryType": HomeDirectoryTypeType,
-        "HomeDirectoryMappings": Sequence["HomeDirectoryMapEntryTypeDef"],
-        "Policy": str,
-        "PosixProfile": "PosixProfileTypeDef",
-        "Role": str,
-    },
-    total=False,
-)
-
-
-class UpdateUserRequestRequestTypeDef(
-    _RequiredUpdateUserRequestRequestTypeDef, _OptionalUpdateUserRequestRequestTypeDef
-):
-    pass
-
 
 UpdateUserResponseTypeDef = TypedDict(
     "UpdateUserResponseTypeDef",
@@ -1254,26 +1003,23 @@ UpdateUserResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUserDetailsTypeDef = TypedDict(
-    "_RequiredUserDetailsTypeDef",
+UserDetailsTypeDef = TypedDict(
+    "UserDetailsTypeDef",
     {
         "UserName": str,
         "ServerId": str,
+        "SessionId": NotRequired[str],
     },
 )
-_OptionalUserDetailsTypeDef = TypedDict(
-    "_OptionalUserDetailsTypeDef",
+
+WaiterConfigTypeDef = TypedDict(
+    "WaiterConfigTypeDef",
     {
-        "SessionId": str,
+        "Delay": NotRequired[int],
+        "MaxAttempts": NotRequired[int],
     },
-    total=False,
 )
 
-
-class UserDetailsTypeDef(_RequiredUserDetailsTypeDef, _OptionalUserDetailsTypeDef):
-    pass
-
-
 WorkflowDetailTypeDef = TypedDict(
     "WorkflowDetailTypeDef",
     {
@@ -1292,11 +1038,10 @@ WorkflowDetailsTypeDef = TypedDict(
 WorkflowStepTypeDef = TypedDict(
     "WorkflowStepTypeDef",
     {
-        "Type": WorkflowStepTypeType,
-        "CopyStepDetails": "CopyStepDetailsTypeDef",
-        "CustomStepDetails": "CustomStepDetailsTypeDef",
-        "DeleteStepDetails": "DeleteStepDetailsTypeDef",
-        "TagStepDetails": "TagStepDetailsTypeDef",
+        "Type": NotRequired[WorkflowStepTypeType],
+        "CopyStepDetails": NotRequired["CopyStepDetailsTypeDef"],
+        "CustomStepDetails": NotRequired["CustomStepDetailsTypeDef"],
+        "DeleteStepDetails": NotRequired["DeleteStepDetailsTypeDef"],
+        "TagStepDetails": NotRequired["TagStepDetailsTypeDef"],
     },
-    total=False,
 )
